@@ -1,6 +1,7 @@
 import tornado.web
 
 from tornado_json.api_doc_gen import api_doc_gen
+from tornado_json.constants import TORNADO_MAJOR
 
 
 class Application(tornado.web.Application):
@@ -21,9 +22,11 @@ class Application(tornado.web.Application):
         # Generate API Documentation
         api_doc_gen(routes)
 
-        # Unless gzip was specifically set to False in settings, enable it
-        if "gzip" not in list(settings.keys()):
-            settings["gzip"] = True
+        # Unless compress_response was specifically set to False in
+        # settings, enable it
+        compress_response = "compress_response" if TORNADO_MAJOR >= 4 else "gzip"
+        if compress_response not in settings:
+            settings[compress_response] = True
 
         tornado.web.Application.__init__(
             self,
